aboutsummaryrefslogtreecommitdiff
path: root/lib/wallet/types.ts
diff options
context:
space:
mode:
Diffstat (limited to 'lib/wallet/types.ts')
-rw-r--r--lib/wallet/types.ts16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/wallet/types.ts b/lib/wallet/types.ts
index 9c7b21b7c..a0e22dbca 100644
--- a/lib/wallet/types.ts
+++ b/lib/wallet/types.ts
@@ -43,11 +43,11 @@ export class AmountJson {
@Checkable.Class
export class CreateReserveResponse {
/**
* Mint URL where the bank should create the reserve.
* The URL is canonicalized in the response.
*/
@Checkable.String
- mint: string;
+ exchange: string;
@Checkable.String
reservePub: string;
@@ -95,14 +95,14 @@ export class Denomination {
}
-export interface IMintInfo {
+export interface IExchangeInfo {
baseUrl: string;
masterPublicKey: string;
denoms: Denomination[];
}
export interface ReserveCreationInfo {
- mintInfo: IMintInfo;
+ exchangeInfo: IExchangeInfo;
selectedDenoms: Denomination[];
withdrawFee: AmountJson;
overhead: AmountJson;
@@ -117,13 +117,13 @@ export interface PreCoin {
blindingKey: string;
withdrawSig: string;
coinEv: string;
- mintBaseUrl: string;
+ exchangeBaseUrl: string;
coinValue: AmountJson;
}
export interface Reserve {
- mint_base_url: string
+ exchange_base_url: string
reserve_priv: string;
reserve_pub: string;
}
@@ -144,7 +144,7 @@ export interface Coin {
denomPub: string;
denomSig: string;
currentAmount: AmountJson;
- mintBaseUrl: string;
+ exchangeBaseUrl: string;
}
@@ -266,4 +266,4 @@ export interface CheckRepurchaseResult {
export interface Notifier {
notify();
-} \ No newline at end of file
+}
@@ -43,11 +43,11 @@ export class AmountJson {
export class CreateReserveResponse {
/**
- * Mint URL where the bank should create the reserve.
+ * Exchange URL where the bank should create the reserve.
* The URL is canonicalized in the response.
*/